@@ -27,6 +27,7 @@ __metaclass__ = type
 __all__ = [
     'Browser',
     'RestfulHttp',
+    'ssl_certificate_validation_disabled',
     ]
 
 import atexit
@@ -40,6 +41,7 @@ import tempfile
 from time import sleep
 from httplib2 import (
     Http,
+    SSLHandshakeError,
     urlnorm,
     )
 import simplejson
@@ -97,6 +99,17 @@ def safename(filename):
     return ",".join((filename, filemd5))
 
 
+def ssl_certificate_validation_disabled():
+    """Whether the user has disabled SSL certificate connection.
+
+    Some testing servers have broken certificates.  Rather than raising an
+    error, we allow an environment variable,
+    ``LP_DISABLE_SSL_CERTIFICATE_VALIDATION`` to disable the check.
+    """
+    return bool(
+        os.environ.get('LP_DISABLE_SSL_CERTIFICATE_VALIDATION', False))
+
+
 class RestfulHttp(Http):
     """An Http subclass with some custom behavior.
 
@@ -109,7 +122,10 @@ class RestfulHttp(Http):
 
     def __init__(self, authorizer=None, cache=None, timeout=None,
                  proxy_info=None):
-        super(RestfulHttp, self).__init__(cache, timeout, proxy_info)
+        cert_disabled = ssl_certificate_validation_disabled()
+        super(RestfulHttp, self).__init__(
+            cache, timeout, proxy_info,
+            disable_ssl_certificate_validation=cert_disabled)
         self.authorizer = authorizer
         if self.authorizer is not None:
             self.authorizer.authorizeSession(self)
@@ -333,8 +349,17 @@ class Browser:
         if extra_headers is not None:
             headers.update(extra_headers)
         # Make the request.
-        response, content = self._request_and_retry(
-            str(url), method=method, body=data, headers=headers)
+        try:
+            response, content = self._request_and_retry(
+                str(url), method=method, body=data, headers=headers)
+        except SSLHandshakeError, e:
+            msg = str(e)
+            if "SSL3_GET_SERVER_CERTIFICATE:certificate verify failed" in msg:
+                raise SSLHandshakeError(
+                    "%s: perhaps set LP_DISABLE_SSL_CERTIFICATE_VALIDATION if "
+                    "certificate validation failed and you genuinely trust the "
+                    "remote server." % (e,))
+            raise
         if response.status == 304:
             # The resource didn't change.
             if content == '':
